==> modello-2.4.0-source-release.zip: modello-2.4.0/modello-core/src/main/java/org/codehaus/modello/Modello.java <==
package org.codehaus.modello;

/*
 * Copyright (c) 2004, Codehaus.org
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import javax.inject.Inject;

import java.io.Reader;
import java.io.Writer;
import java.util.Map;

import org.codehaus.modello.core.ModelloCore;
import org.codehaus.modello.model.Model;
import org.codehaus.modello.model.ModelValidationException;

/**
 * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
 * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
 */
public class Modello {
    private final ModelloCore core;

    @Inject
    public Modello(ModelloCore core) {
        this.core = core;
    }

    public void generate(Reader modelReader, String outputType, Map<String, Object> parameters)
            throws ModelloException, ModelValidationException {
        Model model = core.loadModel(modelReader);

        core.generate(model, outputType, parameters);
    }

    public void translate(Reader reader, Writer writer, String outputType, Map<String, Object> parameters)
            throws ModelloException, ModelValidationException {
        Model model = core.translate(reader, outputType, parameters);

        core.saveModel(model, writer);
    }
}

==> modello-2.5.1-source-release.zip: modello-2.5.1/modello-core/src/main/java/org/codehaus/modello/Modello.java <==
package org.codehaus.modello;

/*
 * Copyright (c) 2004, Codehaus.org
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import java.io.Reader;
import java.io.Writer;
import java.util.Map;

import org.codehaus.modello.core.ModelloCore;
import org.codehaus.modello.model.Model;
import org.codehaus.modello.model.ModelValidationException;
import org.codehaus.plexus.DefaultContainerConfiguration;
import org.codehaus.plexus.DefaultPlexusContainer;
import org.codehaus.plexus.PlexusConstants;

/**
 * @author <a href="mailto:jason@maven.org">Jason van Zyl</a>
 * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
 */
public class Modello {
    private final ModelloCore core;

    public Modello() throws ModelloException {
        try {
            this.core = new DefaultPlexusContainer(new DefaultContainerConfiguration()
                            .setClassPathScanning(PlexusConstants.SCANNING_INDEX)
                            .setAutoWiring(true))
                    .lookup(ModelloCore.class);
        } catch (Exception e) {
            throw new ModelloException("Error while starting plexus.", e);
        }
    }

    public void generate(Reader modelReader, String outputType, Map<String, Object> parameters)
            throws ModelloException, ModelValidationException {
        Model model = core.loadModel(modelReader);

        core.generate(model, outputType, parameters);
    }

    public void translate(Reader reader, Writer writer, String outputType, Map<String, Object> parameters)
            throws ModelloException, ModelValidationException {
        Model model = core.translate(reader, outputType, parameters);

        core.saveModel(model, writer);
    }
}
